//
//  TitleLayer.m
//  Game01
//
//  Created by Kansuke Nishida on 11/09/18.
//  Copyright 2011年 tonosamart. All rights reserved.
//

#import "SimpleAudioEngine.h"
#import "TitleLayer.h"
#import "GameScene.h"

@interface TitleLayer (private)
-(CGRect)rectForSprite:(CCSprite *)sprite;
-(void)initLayer;
-(void)tick:(ccTime)dt;
-(void)menuStart:(id)sender;
-(void)delSprite:(id)node;
@end

@implementation TitleLayer

enum {
    SPRITE_NULL,
    SPRITE_PLAYER,
    SPRITE_TEXT,
    SPRITE_MENU
};

- (id)init{
    self = [super init];
    if (self) {
        // イベントの無効/有効
        self.isTouchEnabled = YES;
        self.isAccelerometerEnabled = NO;
        
        //レイヤーの初期化
        [self initLayer];
    }
    
    return self;
}

#pragma mark private

-(CGRect)rectForSprite:(CCSprite *)sprite{
	float w = sprite.contentSize.width * sprite.scaleX;
	float h = sprite.contentSize.height * sprite.scaleY;
	float x = sprite.position.x - (w * sprite.anchorPoint.x);
	float y = sprite.position.y - (h * sprite.anchorPoint.y);
    return CGRectMake(x, y, w, h);
}

-(void)initLayer{
    CCSprite* sprite = [CCSprite spriteWithFile:@"free03_179.png"];
    sprite.position = ccp(0, 160);
    [self addChild:sprite z:SPRITE_PLAYER tag:SPRITE_PLAYER];

    //---
    
    CCLabelTTF* label = [CCLabelTTF labelWithString:@"PANDA GAME" fontName:@"retrogame" fontSize:48];
    label.color = ccc3(255, 0, 0);
    label.position = ccp(240, 240);
    [self addChild:label z:SPRITE_TEXT tag:SPRITE_TEXT]; 
    
    [CCMenuItemFont setFontName:@"Marker Felt"];
    [CCMenuItemFont setFontSize:32];
    CCMenuItem *startButton = [CCMenuItemFont itemFromString:@"START" target:self selector:@selector(menuStart:)];
    startButton.position = ccp(240, 80);
    
    CCMenu *menu = [CCMenu menuWithItems:startButton, nil];
    menu.position = ccp(0,0);
    [self addChild:menu z:SPRITE_MENU tag:SPRITE_MENU];
    
    //---
    [[SimpleAudioEngine sharedEngine] preloadEffect:@"coin.caf"];
    
    //---
    [self schedule:@selector(tick:)];

}

-(void)tick:(ccTime)dt{
    CCSprite* sprite = (CCSprite*)[self getChildByTag:SPRITE_PLAYER];
    sprite.position = ccp(sprite.position.x + (100.0f * dt), sprite.position.y);
}

-(void)menuStart:(id)sender{
    [[SimpleAudioEngine sharedEngine] playEffect:@"coin.caf"];
}

-(void)delSprite:(id)node{
    [node removeFromParentAndCleanup:YES];
}

#pragma mark EVENT

-(void)ccTouchesBegan:(NSSet *)touches withEvent:(UIEvent *)event {
	for(UITouch* touch in touches){
		CGPoint touchPoint = [touch locationInView:[touch view]];
		touchPoint = [[CCDirector sharedDirector] convertToGL:touchPoint];
		
		if(CGRectContainsPoint([self rectForSprite:(CCSprite*)[self getChildByTag:SPRITE_PLAYER]], touchPoint)){
            [[SimpleAudioEngine sharedEngine] playEffect:@"coin.caf"];
		}
	}
}

-(void)ccTouchesMoved:(NSSet *)touches withEvent:(UIEvent *)event {
}

-(void)ccTouchesEnded:(NSSet *)touches withEvent:(UIEvent *)event {
}

-(void)ccTouchesCancelled:(NSSet *)touches withEvent:(UIEvent *)event {
}

@end

